@@ -75,6 +75,7 @@
 #define HAVE_UCONTEXT_H 1
 #define HAVE_UTIME_H 1
 #define HAVE_SYS_EPOLL_H 1
+#define HAVE_STDCKDINT_H 1
 #define HAVE_STDATOMIC_H 1
 #define HAVE_GMP_H 1
 #define HAVE_LIBGMP 1
@@ -324,7 +325,6 @@
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_GETUID 1
 #define HAVE_GMTIME_R 1
-#define HAVE_GRANTPT 1
 #define HAVE_INITGROUPS 1
 #define HAVE_IOCTL 1
 #define HAVE_KILL 1
@@ -420,16 +420,20 @@
 #define HAVE_BUILTIN___BUILTIN_CLZLL 1
 #define HAVE_BUILTIN___BUILTIN_CTZ 1
 #define HAVE_BUILTIN___BUILTIN_CTZLL 1
-#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW_P 1
 #define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
 #define HAVE_BUILTIN___BUILTIN_TRAP 1
 #define HAVE_BUILTIN___BUILTIN_EXPECT 1
+#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW_P 1
+#define USE___BUILTIN_ADD_OVERFLOW_LONG_LONG 1
+#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW_P 1
+#define USE___BUILTIN_SUB_OVERFLOW_LONG_LONG 1
+#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW_P 1
 #define USE___BUILTIN_MUL_OVERFLOW_LONG_LONG 1
 #define HAVE_GNU_QSORT_R 1
 #define ATAN2_INF_C99 1
@@ -474,11 +478,14 @@
 #define HAVE_BACKTRACE 1
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
+#define SOEXT ".so"
 #define LIBDIR_BASENAME "lib"
 #define HAVE__SETJMP 1
 #define RUBY_SETJMP(env) __builtin_setjmp((env))
 #define RUBY_LONGJMP(env,val) __builtin_longjmp((env),val)
+#define USE_MODULAR_GC 0
 #define USE_YJIT 0
 #define USE_RJIT 0
 #define RUBY_PLATFORM "armv7l-linux-eabihf"
+#define RB_DEFAULT_PARSER RB_DEFAULT_PARSER_PRISM
 #endif /* INCLUDE_RUBY_CONFIG_H */
