@@ -9,20 +9,20 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.3.") or
-    raise "ruby lib version (3.3.7) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.4.") or
+    raise "ruby lib version (3.4.3) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.3.0/armv7l-linux-eabihf")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.4.0/armv7l-linux-eabihf")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "3"
-  CONFIG["TEENY"] = "7"
-  CONFIG["PATCHLEVEL"] = "123"
+  CONFIG["MINOR"] = "4"
+  CONFIG["TEENY"] = "3"
+  CONFIG["PATCHLEVEL"] = "32"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr")
@@ -30,7 +30,7 @@ module RbConfig
   CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.3.pc"
+  CONFIG["ruby_pc"] = "ruby-3.4.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wno-incompatible-pointer-types' 'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now' 'CPPFLAGS=' 'CXXFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Wno-incompatible-pointer-types'"
+  CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wno-incompatible-pointer-types' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' 'CPPFLAGS=' 'CXXFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Wno-incompatible-pointer-types'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -55,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.3.0"
+  CONFIG["ruby_version"] = "3.4.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "armv7l-linux-eabihf"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -97,6 +97,7 @@ module RbConfig
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
+  CONFIG["hardenflags"] = "-fstack-protector-strong -U_FORTIFY_SOURCE -D_FORTIFY_SOURCE=2"
   CONFIG["strict_warnflags"] = ""
   CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdiv-by-zero -Wduplicated-cond -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wold-style-definition -Wimplicit-fallthrough=0 -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-packed-bitfield-compat -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wsuggest-attribute=format -Wsuggest-attribute=noreturn -Wunused-variable -Wmisleading-indentation -Wundef"
   CONFIG["debugflags"] = "-ggdb3"
@@ -112,6 +113,7 @@ module RbConfig
   CONFIG["CARGO"] = ""
   CONFIG["RUSTC"] = "rustc"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "no"
+  CONFIG["modular_gc_dir"] = ""
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
@@ -126,8 +128,8 @@ module RbConfig
   CONFIG["PRELOADENV"] = "LD_PRELOAD"
   CONFIG["LIBPATHENV"] = "LD_LIBRARY_PATH"
   CONFIG["RPATHFLAG"] = ""
-  CONFIG["LIBPATHFLAG"] = " -L%s"
-  CONFIG["LINK_SO"] = ""
+  CONFIG["LIBPATHFLAG"] = "-L%s"
+  CONFIG["LINK_SO"] = "\n$(POSTLINK)"
   CONFIG["ADDITIONAL_DLDFLAGS"] = ""
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
@@ -139,7 +141,7 @@ module RbConfig
   CONFIG["CCDLFLAGS"] = "-fPIC"
   CONFIG["STATIC"] = ""
   CONFIG["ARCH_FLAG"] = ""
-  CONFIG["DLDFLAGS"] = "-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now -Wl,--compress-debug-sections=zlib"
+  CONFIG["DLDFLAGS"] = "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -Wl,--compress-debug-sections=zlib"
   CONFIG["ALLOCA"] = ""
   CONFIG["EGREP"] = "/usr/bin/grep -E"
   CONFIG["GREP"] = "/usr/bin/grep"
@@ -167,7 +169,6 @@ module RbConfig
   CONFIG["LN_S"] = "ln -s"
   CONFIG["DLLWRAP"] = ""
   CONFIG["WINDRES"] = ""
-  CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
   CONFIG["CC_VERSION_MESSAGE"] = "armv7l-unknown-linux-gnueabihf-gcc (GCC) 14.2.1 20250207\nCopyright (C) 2024 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
@@ -182,7 +183,7 @@ module RbConfig
   CONFIG["CXXFLAGS"] = "-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Wno-incompatible-pointer-types"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = " $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now -fstack-protector-strong -rdynamic -Wl,-export-dynamic -Wl,--no-as-needed"
+  CONFIG["LDFLAGS"] = "-L. -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -fstack-protector-strong -rdynamic -Wl,-export-dynamic -Wl,--no-as-needed"
   CONFIG["CFLAGS"] = "-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wno-incompatible-pointer-types -fPIC"
   CONFIG["STRIP"] = "strip -S -x"
   CONFIG["RANLIB"] = "gcc-ranlib"
@@ -196,6 +197,7 @@ module RbConfig
   CONFIG["CC"] = "gcc"
   CONFIG["wasmoptflags"] = ""
   CONFIG["WASMOPT"] = ""
+  CONFIG["config_target"] = "armv7l-unknown-linux-gnueabihf"
   CONFIG["target_os"] = "linux-eabihf"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "armv7l"
@@ -217,7 +219,7 @@ module RbConfig
   CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
-  CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cflags"] = "$(hardenflags)  $(optflags) $(debugflags) $(warnflags)"
   CONFIG["MAKEDIRS"] = "/usr/bin/mkdir -p"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = "$(target_alias)"
